<h1 align="center"> chatgpt-anon </h1>

<p align="center">
<a href="https://github.com/Simatwa/chatgpt-anon/actions/workflows/python-test.yml"><img src="https://github.com/Simatwa/chatgpt-anon/actions/workflows/python-test.yml/badge.svg" alt="Python Test"/></a>
<a href="LICENSE"><img alt="License" src="https://img.shields.io/static/v1?logo=GPL&color=Blue&message=GNUv3&label=License"/></a>
<a href="https://pypi.org/project/chatgpt-anon"><img alt="PyPi" src="https://img.shields.io/pypi/v/chatgpt-anon?color=green"/></a>
<a href="https://github.com/psf/black"><img alt="Black" src="https://img.shields.io/static/v1?logo=Black&label=Code-style&message=Black"/></a>
<a href="#"><img alt="Passing" src="https://img.shields.io/static/v1?logo=Docs&label=Docs&message=Passing&color=green"/></a>
<a href="#"><img alt="coverage" src="https://img.shields.io/static/v1?logo=Coverage&label=Coverage&message=90%&color=yellowgreen"/></a>
<a href="https://pepy.tech/project/chatgpt-anon"><img src="https://static.pepy.tech/personalized-badge/chatgpt-anon?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads" alt="Downloads"></a>
<!--<a href="https://github.com/Simatwa/chatgpt-anon/releases"><img src="https://img.shields.io/github/downloads/Simatwa/chatgpt-anon/total?label=Downloads&color=success" alt="Downloads"></img></a> -->
<a href="https://github.com/Simatwa/chatgpt-anon/releases"><img src="https://img.shields.io/github/v/release/Simatwa/chatgpt-anon?color=success&label=Release&logo=github" alt="Latest release"></img></a>
<a href="https://github.com/Simatwa/chatgpt-anon/releases"><img src="https://img.shields.io/github/release-date/Simatwa/chatgpt-anon?label=Release date&logo=github" alt="release date"></img></a>
<a href="https://hits.seeyoufarm.com"><img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com/Simatwa/chatgpt-anon"/></a>
<a href="https://wakatime.com/badge/github/Simatwa/chatgpt-anon"><img src="https://wakatime.com/badge/github/Simatwa/chatgpt-anon.svg" alt="wakatime"></a>
</p>

Intreract with ChatGPT anonymously.
